@@ -104,13 +104,13 @@ HR {
 }
 IMG {border: 0;}
 
-A:link	  {color: #fff; text-decoration: underline; font-weight:bold;}
-A:visited {color: #fff; text-decoration: underline; font-weight:bold;}
-A:hover   {color: #fff; text-decoration: none; font-weight:bold;}
-A:active  {color: #fff; text-decoration: none; font-weight:bold;}
+A:link	  {color: #fff; text-decoration: underline; font-weight:normal;}
+A:visited {color: #fff; text-decoration: underline; font-weight:normal;}
+A:hover   {color: #fff; text-decoration: none; font-weight:normal;}
+A:active  {color: #fff; text-decoration: none; font-weight:normal;}
 
 H1 {
-	font-family: "Verdana", "Arial", "Helvetica", sans-serif;
+	font-family: "Verdana", "DejaVu Sans", "Arial Bold", "Arial", "Helvetica", sans-serif;
 	font-weight: bold;
 	font-size: large;
 	<?php echo "font-size: $font_size_large" ?>;
@@ -180,7 +180,7 @@ H6 {
 
 .logo {
 	vertical-align:	middle;
-	font-family:	'Verdana', sans-serif;
+	font-family:	"Verdana", "DejaVu Sans", "Arial Bold", sans-serif;
 	font-size: large;
 	<?php echo "font-size: $font_size_large" ?>;
 	font-weight:	bold;
@@ -262,7 +262,7 @@ H6 {
 	<?php echo "font-size: $font_size_large" ?>;
 	margin:	0;
 	margin-top:	0;
-	margin-bottom:	1em;
+	margin-bottom:	0;
 	padding:	0;
 	letter-spacing:	0.1em;
 }
@@ -330,13 +330,13 @@ A.footer:active  { color: #789; font-weight: normal; }
 	float:	right;
 	width:	300px;
 	padding:	1em;
-	margin-top:		0;
+	margin-top: 1em;
 	margin-left:	1em;
 	margin-bottom:	1em;
 }
-.news-home  { background-color: #345; margin-top: -2em; }
-.news-about { background-color: #865; }
-.news-down  { background-color: #584; margin-top: -2em;}
+.news-home  { background-color: #345;}
+.news-about { background-color: #865;}
+.news-down  { background-color: #584;}
 
 .nolead {
 	margin-top: 0;
